Crate rs_car_ipfs

Crate rs_car_ipfs 

Wrapper for rs-car to read files from IPFS trustless gateways with an async API.

Usage

Modules

single_file
CAR stream does not include duplicated blocks, so to reconstruct a unixfs file, data does not follow the same layout as the expected target file. To recreate the file one must have the ability to read from arbitrary locations of the stream.

Type Aliases

Cid
A Cid that contains a multihash with an allocated size of 512 bits.